This is an automated email from the git hooks/post-receive script.

git pushed a commit to branch tymux
in repository terminology.

View the commit online.

commit b53e7e46a15ffa4026dccd576e90453cabdfeec0
Author: [email protected] <[email protected]>
AuthorDate: Sat Mar 21 17:06:25 2026 -0600

    fix: change proxy detach key from Ctrl+\ to Ctrl+]
    
    Ctrl+\ (0x1C, VQUIT) may not be generated correctly on all keyboard
    layouts. Switch to Ctrl+] (0x1D), which is the standard escape
    character used by telnet and netcat — more universally supported.
    
    Co-Authored-By: Claude Opus 4.6 (1M context) <[email protected]>
---
 src/bin/tymux.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/src/bin/tymux.c b/src/bin/tymux.c
index 72c50bd5..a5d3a020 100644
--- a/src/bin/tymux.c
+++ b/src/bin/tymux.c
@@ -995,7 +995,7 @@ cmd_new(int argc, char **argv)
  * Connects to tymuxd, sends ATTACH, receives ATTACHED + memfd, then takes
  * over the current terminal: puts it in raw mode, polls stdin and the
  * daemon socket in a tight loop, renders shm cells on NOTIFY, and forwards
  * stdin bytes as TSRV_MSG_INPUT.  Detach key: Ctrl+\ (0x1C).
  */
 static int
 cmd_attach(int argc, char **argv)
@@ -1212,10 +1212,10 @@ cmd_attach(int argc, char **argv)
                }
              if (nr == 0) { running = 0; break; }
 
              /* Scan for detach key: Ctrl+\ (0x1C, like GNU screen) */
              for (ssize_t i = 0; i < nr; i++)
                {
-                  if ((unsigned char)ibuf[i] == 0x1C)
+                  if ((unsigned char)ibuf[i] == 0x1D)
                     {
                        /* Detach: send DETACH then exit loop */
                        _proto_send(sock, _TSRV_MSG_DETACH, NULL, 0);
@@ -1340,7 +1340,7 @@ usage(const char *prog)
           "                        then launch terminology attached to it\n"
           "  attach <name>         Attach to a running background terminal\n"
           "                        (takes over the current terminal, like tmux attach)\n"
-          "                        Detach with Ctrl+\\ (Ctrl-backslash)\n"
+          "                        Detach with Ctrl+] (Ctrl-bracket)\n"
           "\n"
           "Environment:\n"
           "  XDG_RUNTIME_DIR       Base directory for tymux sockets\n"
@@ -995,7 +995,7 @@ cmd_new(int argc, char **argv)
  * over the current terminal: puts it in raw mode, polls stdin and the
  * daemon socket in a tight loop, renders shm cells on NOTIFY, and forwards
- * stdin bytes as TSRV_MSG_INPUT.  Detach key: Ctrl+\ (0x1C).
+ * stdin bytes as TSRV_MSG_INPUT.  Detach key: Ctrl+] (0x1D).
  */
 static int
@@ -1212,10 +1212,10 @@ cmd_attach(int argc, char **argv)
              if (nr == 0) { running = 0; break; }
 
-             /* Scan for detach key: Ctrl+\ (0x1C, like GNU screen) */
+             /* Scan for detach key: Ctrl+] (0x1D) */
              for (ssize_t i = 0; i < nr; i++)
                {

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.

Reply via email to